/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "scalebardialog.h"

ScalebarDialog::ScalebarDialog(double pixelSize, QWidget *parent)
    : QDialog(parent)
{
    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setWindowTitle(tr("Scale Option"));

    scaleUnitsComboBox = new QComboBox;
    scaleUnitsComboBox->addItem("cm");
    scaleUnitsComboBox->addItem("dm");
    scaleUnitsComboBox->addItem("m");
    scaleUnitsComboBox->addItem("km");
    scaleUnitsComboBox->setCurrentIndex(2);

    QStringList scaleFactorList;
    scaleFactorList << "0.5" << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8" << "9" << "10" << "15" << "20";

    scaleFactorComboBox = new QComboBox(this);
    scaleFactorComboBox->addItems(scaleFactorList);
    scaleFactorComboBox->setCurrentIndex(1);

    QString scaleStr(tr("Pixel size: 1 pixel = "));
    scaleStr.append(QString::number(pixelSize, 'f', 4)).append(" m");

    QLabel *scaleLabel = new QLabel(scaleStr, this);
    QLabel *scaleUnitLabel = new QLabel(tr("Select scale bar units:"), this);
    QLabel *scaleFactorLabel = new QLabel(tr("Select division value multiple:"), this);
    QLabel *scaleSizeLabel = new QLabel(tr("Select text size (10 to 50):"), this);
    QLabel *finishLabel = new QLabel (tr("Place the scale bar into the image and press the Finish button."), this);

    scaleSizeBox = new QSpinBox(this);
    scaleSizeBox->setRange(10, 50);

    finishButton = new QPushButton(tr("Finish"), this);
    finishButton->setEnabled(false);

    QGridLayout *layout = new QGridLayout;
    QGridLayout *finishLayout = new QGridLayout;
    QGridLayout *mainLayout = new QGridLayout;

    layout->addWidget(scaleLabel, 0, 0);
    layout->addWidget(scaleUnitLabel, 1, 0);
    layout->addWidget(scaleUnitsComboBox, 1, 1);
    layout->addWidget(scaleFactorLabel, 2, 0);
    layout->addWidget(scaleFactorComboBox, 2, 1);
    layout->addWidget(scaleSizeLabel, 3, 0);
    layout->addWidget(scaleSizeBox, 3, 1);

    finishLayout->addWidget(finishLabel, 0, 0);
    finishLayout->addWidget(finishButton, 1, 0);

    mainLayout->addLayout(layout, 0, 0);
    mainLayout->addLayout(finishLayout, 1, 0);

    setLayout(mainLayout);
}

QSpinBox* ScalebarDialog::getScaleSizeBox()
{
    return scaleSizeBox;
}

QComboBox* ScalebarDialog::getScaleUnitsComboBox()
{
    return scaleUnitsComboBox;
}

QComboBox* ScalebarDialog::getScaleFactorComboBox()
{
    return scaleFactorComboBox;
}

QPushButton* ScalebarDialog::getFinishButton()
{
    return finishButton;
}

