/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#ifndef TABLEOFPOINTS_H
#define TABLEOFPOINTS_H

#include <QtGui>
#include <eigen2/Eigen/Core>
#include <eigen2/Eigen/lu>

USING_PART_OF_NAMESPACE_EIGEN

class TableOfPoints : public QDialog
{
    Q_OBJECT

public:
    TableOfPoints(int pointCount, QWidget *parent = 0);
    void insertData(Matrix<double, 9, 2> objectXY, QList<QLabel*> imageXY, bool network);

    QList<QCheckBox*> getCheckBoxList();

    QList<QDoubleSpinBox*> getObjectXList();
    QList<QDoubleSpinBox*> getObjectYList();

    QTableWidget* getTable();

    QPushButton* getTransformButton();
    QPushButton* getSkipButton();
    QPushButton* getSaveTableButton();
    QPushButton* getLoadCoordsButton();
    QPushButton* getShowResidualsButton();

private:
    void showData(QList<QLabel*> imageXY, bool networkMethod);
    void enableButtons(bool networkMethod);
    QTableWidget *table;

    QPushButton *showResidualsButton;
    QPushButton *transformButton;
    QPushButton *saveTableButton;
    QPushButton *loadCoordsButton;
    QPushButton *skipButton;

    QCheckBox *usePointCheckBox;

    QDoubleSpinBox *objectX;
    QDoubleSpinBox *objectY;

    QList<QCheckBox*> checkBoxList;
    QList<QDoubleSpinBox*> objectXList;
    QList<QDoubleSpinBox*> objectYList;

    QTableWidgetItem *item;

    int rowCount;
};

#endif // TABLEOFPOINTS_H
